#!/bin/bash

# Stop script on error
set -e

# Don't allow unassigned variables
set -u


##############
#
# Purpose:
# This script installs the Movek myMix Control web application an unmodifed
# plug computer.
#
##############


############## Script variables
# The root password for resulting myMix Control plug computers. Anyone who knows
# this password can get full root access to the plug computer!
rootpw="nosoup4u"


############## Confirm installation
# In case someone runs this script accedentally
read -p "Install myMix Control application on this computer? (y/N)" -n 1
echo ""
if [[ ! $REPLY =~ ^[Yy]$ ]]
then
	echo "Exiting..."
    exit 1
fi

# Print commands as they are executed for the remainder of the script
set -x


############## Prepare for installation
# change to the installation source directory
cd /media/usb
# extract the installation files if they haven't been already
if [ ! -f users.xml ]; then
    tar --no-same-owner --strip-components=1 -xzf install.tgz
fi


############## First, attempt installation items that are most likely to fail
# Install non-NAT wifi configuration
if [ -f /root/init_setup8787.sh ]; then
    cp init_setup8787.sh /root/init_setup8787.sh
elif [ -f /root/init_setup.sh ]; then
    cp init_setup.sh /root/init_setup.sh
else
    +x
    echo "Could not determine which wifi configuration to install, exiting...";
    exit 1
fi


############## Install application
# Remove default plug application
rm -rf /var/www/*

# Install default application data, if none is present
if [ ! -d /var/movek ]; then
    mkdir /var/movek
    mkdir /var/movek/active-project
    cp users.xml /var/movek/
    chown -R www-data:www-data /var/movek
fi

# Install system (update) application
mkdir /var/www/system
tar --directory /var/www/system/ --strip-components=1 -xzf system.tgz

# Install myMix Control application
mkdir /var/www/app
tar --directory /var/www/app/ --strip-components=1 -xzf update.tgz

# Make sure lighttpd has access to all the application folders
chown -R www-data:www-data /var/www


############## Change permissions and mountpoints
chown -R www-data:www-data /var/log/lighttpd
chmod 777 /tmp

# Mount tmpfs on /tmp
echo "tmpfs /tmp tmpfs rw,noexec,nosuid,nodev 0 0" >> /etc/fstab
rm -rf /tmp/*
mount /tmp


############## Install required software packages
dpkg --auto-deconfigure --force-confold -i packages/*.deb


############## Change/install config files
# Install PHP configuration
#/etc/php5/cgi/php.ini "session.save_path" = /tmp
cp php.ini /etc/php5/cgi/php.ini

# Enable php module
lighttpd-enable-mod fastcgi-php
/etc/init.d/lighttpd force-reload
#pwd=`pwd`
#cd /etc/lighttpd/conf-enabled/
#ln -s ../conf-available/15-fastcgi-php.conf
#cd "$pwd"

# Install lighttpd configuration
#enable alias for system application
cp lighttpd.conf /etc/lighttpd/lighttpd.conf

# Remove automatically installed index file
rm /var/www/index.lighttpd.html


############## Change root password
passwd <<EOF
${rootpw}
${rootpw}
EOF

############## Sync changes to disk
sync


############## Print success message
set +x
echo ""
echo "############################"
echo "#                          #"
echo "# Installation successful! #"
echo "#                          #"
echo "############################"

############## End of script
